DefaultStreamBottomAppBar class
The default implementation of StreamBottomAppBar.
This widget renders the bottom app bar with theming support from StreamBottomAppBarTheme. It's used as the default factory implementation in StreamComponentFactory.
The title slot is centred in the bar's full inner width via StreamToolbar, which reserves symmetric space around the middle so an asymmetric leading and trailing don't shift the title off-centre.
See also:
- StreamBottomAppBar, the public API widget.
- StreamBottomAppBarProps, which configures this widget.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DefaultStreamBottomAppBar
Constructors
- DefaultStreamBottomAppBar({Key? key, required StreamBottomAppBarProps props})
-
Creates a default bottom app bar with the given
props.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- props → StreamBottomAppBarProps
-
The properties that configure this bottom app bar.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited