StreamAvatarGroupProps class

Properties for configuring a StreamAvatarGroup.

This class holds all the configuration options for an avatar group, allowing them to be passed through the StreamComponentFactory.

See also:

Constructors

StreamAvatarGroupProps({StreamAvatarGroupSize? size, required Iterable<Widget> children})
Creates properties for an avatar group.
const

Properties

children Iterable<Widget>
The list of avatars to display in the group.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size StreamAvatarGroupSize?
The size of the avatar group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited