StreamAvatarThemeData class

Theme data for customizing StreamAvatar widgets.

{@tool snippet}

Customize avatar appearance globally:

StreamTheme(
  avatarTheme: StreamAvatarThemeData(
    backgroundColor: Colors.grey.shade200,
    foregroundColor: Colors.grey.shade800,
    border: Border.all(color: Colors.grey.shade300, width: 2),
  ),
)

{@end-tool}

See also:

Annotations

Constructors

StreamAvatarThemeData({StreamAvatarSize? size, Color? backgroundColor, Color? foregroundColor, BoxBorder? border})
Creates an avatar theme with optional style overrides.
const

Properties

backgroundColor Color?
The background color for this avatar.
final
border BoxBorder?
The border for this avatar.
final
canMerge bool
no setterinherited
foregroundColor Color?
The foreground color for this avatar's placeholder content.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size StreamAvatarSize?
The default size for avatars.
final

Methods

copyWith({StreamAvatarSize? size, Color? backgroundColor, Color? foregroundColor, BoxBorder? border}) StreamAvatarThemeData
inherited
merge(StreamAvatarThemeData? other) StreamAvatarThemeData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(StreamAvatarThemeData? a, StreamAvatarThemeData? b, double t) StreamAvatarThemeData?
Linearly interpolate between two StreamAvatarThemeData objects.