StreamBadgeNotificationProps class

Properties for configuring a StreamBadgeNotification.

This class holds all the configuration options for a badge notification, allowing them to be passed through the StreamComponentFactory.

See also:

Constructors

StreamBadgeNotificationProps({StreamBadgeNotificationType? type, StreamBadgeNotificationSize? size, required String label, String? semanticLabel, Widget? child, AlignmentGeometry? alignment, Offset? offset})
Creates properties for a badge notification.
const

Properties

alignment AlignmentGeometry?
The alignment of the badge relative to child.
final
child Widget?
The widget below this widget in the tree.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The text label to display in the badge.
final
offset Offset?
The offset for fine-tuning badge position.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
An alternative label spoken by screen readers in place of label.
final
size StreamBadgeNotificationSize?
The size of the badge.
final
type StreamBadgeNotificationType?
The visual type determining the badge background color.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited