StreamCheckboxProps class

Properties for configuring a StreamCheckbox.

This class holds all the configuration options for a checkbox, allowing them to be passed through the StreamComponentFactory.

See also:

Constructors

StreamCheckboxProps({required bool value, required ValueChanged<bool>? onChanged, StreamCheckboxSize? size, OutlinedBorder? shape, String? semanticLabel})
Creates properties for a checkbox.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onChanged ValueChanged<bool>?
Called when the value of the checkbox should change.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
The semantic label for the checkbox that will be announced by screen readers.
final
shape OutlinedBorder?
The shape of the checkbox.
final
size StreamCheckboxSize?
The size of the checkbox.
final
value bool
Whether this checkbox is checked.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited