props property
The props controlling the appearance and behavior of this action.
Implementation
final StreamContextMenuActionProps<T> props;
The props controlling the appearance and behavior of this action.
final StreamContextMenuActionProps<T> props;