isSelected property
Whether the button is in a selected state.
When true, the button displays selected styling. When false or null, the button is not selected.
Implementation
final bool? isSelected;
Whether the button is in a selected state.
When true, the button displays selected styling. When false or null, the button is not selected.
final bool? isSelected;