StreamEmojiButtonThemeStyle class

Visual styling properties for emoji buttons.

Defines the appearance of emoji buttons including size, colors, and borders. All color properties support state-based styling for interactive feedback.

See also:

Annotations

Constructors

StreamEmojiButtonThemeStyle({StreamEmojiButtonSize? size, WidgetStateProperty<Color?>? backgroundColor, WidgetStateProperty<Color?>? foregroundColor, WidgetStateProperty<Color?>? overlayColor, WidgetStateProperty<BorderSide?>? side})
Creates emoji button style properties.
const

Properties

backgroundColor WidgetStateProperty<Color?>?
The background color for emoji buttons.
final
canMerge bool
no setterinherited
foregroundColor WidgetStateProperty<Color?>?
The foreground color for emoji/icon content.
final
hashCode int
The hash code for this object.
no setterinherited
overlayColor WidgetStateProperty<Color?>?
The overlay color for the button's interaction feedback.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side WidgetStateBorderSide?
The border for the button.
final
size StreamEmojiButtonSize?
The size of emoji buttons.
final

Methods

copyWith({StreamEmojiButtonSize? size, WidgetStateProperty<Color?>? backgroundColor, WidgetStateProperty<Color?>? foregroundColor, WidgetStateProperty<Color?>? overlayColor, WidgetStateBorderSide? side}) StreamEmojiButtonThemeStyle
inherited
merge(StreamEmojiButtonThemeStyle? other) StreamEmojiButtonThemeStyle
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(StreamEmojiButtonThemeStyle? a, StreamEmojiButtonThemeStyle? b, double t) StreamEmojiButtonThemeStyle?
Linearly interpolate between two StreamEmojiButtonThemeStyle objects.