StreamEmojiPickerSheet class

A scrollable sheet that displays a curated set of emojis in a flat grid.

The recommended way to display the picker is via the show method, which presents it as a modal bottom sheet and returns the selected emoji.

The emoji buttons are styled using StreamEmojiButtonTheme.

{@tool snippet}

final emoji = await StreamEmojiPickerSheet.show(
  context: context,
);
if (emoji != null) {
  sendReaction(emoji);
}

{@end-tool}

See also:

Inheritance

Properties

emojiButtonSize StreamEmojiButtonSize?
The size of each emoji button in the grid.
final
emojis Iterable<StreamEmojiData>
The emojis to display in the grid.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
The scroll controller for the emoji grid.
final
selectedReactions Set<String>?
The set of emoji short names that are currently selected.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, Iterable<StreamEmojiData>? emojis, StreamEmojiButtonSize? emojiButtonSize, Set<String>? selectedReactions, Color? backgroundColor}) Future<StreamEmojiData?>
Shows the emoji picker as a modal bottom sheet.