StreamEmojiProps class

Properties for configuring a StreamEmoji.

This class holds all the configuration options for an emoji, allowing them to be passed through the StreamComponentFactory.

See also:

Annotations

Constructors

StreamEmojiProps({StreamEmojiSize? size, required StreamEmojiContent emoji, TextScaler? textScaler})
Creates emoji properties.
const

Properties

emoji StreamEmojiContent
The content model describing what to render.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size StreamEmojiSize?
The display size of the emoji.
final
textScaler TextScaler?
A TextScaler to apply to the emoji dimensions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited