StreamHelperState enum

The state of helper text, driving the icon and color.

Used by StreamHelperText and StreamTextInput to select the appropriate visual treatment for informational messages displayed below a text input.

See also:

Inheritance
Available extensions

Values

info → const StreamHelperState

Neutral informational state.

error → const StreamHelperState

Error state — indicates validation failure or other problems.

success → const StreamHelperState

Success state — indicates valid input or completion.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StreamHelperState>
A constant List of the values in this enum, in order of their declaration.