StreamImageEmoji class

A custom image emoji loaded from a URL.

Covers custom emoji such as Twitch, Discord, or Reddit emotes, as well as cross-platform image sets like Twemoji.

See also:

Inheritance
Annotations

Constructors

StreamImageEmoji({required Uri url, Uri? stillUrl})
Creates an image emoji display.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stillUrl Uri?
An optional URL for the still (non-animated) version of the emoji.
final
url Uri
The URL of the emoji image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited