StreamImageSourceBadge class

A pill-shaped overlay badge that identifies the source of content.

StreamImageSourceBadge displays a leading icon alongside a label in a semi-transparent dark pill. It's used as an image overlay to indicate the origin of media content (e.g., Giphy, Imgur).

Pre-built badges are available for common sources:

StreamImageSourceBadge.giphy
StreamImageSourceBadge.imgur

{@tool snippet}

Custom usage:

StreamImageSourceBadge(
  leading: SvgIcon(context.streamIcons.giphy),
  label: Text('GIPHY'),
)

{@end-tool}

See also:

Inheritance

Constructors

StreamImageSourceBadge({Key? key, required Widget leading, required Widget label, Color? backgroundColor, Color? foregroundColor})
Creates a source badge with the given leading icon and label.

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
props StreamImageSourceBadgeProps
The properties that configure this source badge.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

giphy Widget
A Giphy source badge.
getter/setter pair
imgur Widget
An Imgur source badge.
getter/setter pair