StreamJumpToUnreadButton class

A floating pill-shaped button for jumping to unread messages.

The button has two sections separated by a vertical divider:

  • A leading tap area with an icon and a label (a String).
  • A trailing icon button (typically for dismiss).

The leading and trailing sections are built using StreamButton and StreamButton.icon respectively, inheriting their interaction states (hover, pressed) from the design system.

{@tool snippet}

Basic usage:

StreamJumpToUnreadButton(
  label: '3 unread',
  onJumpPressed: () => scrollToUnread(),
  onDismissPressed: () => markAsRead(),
)

{@end-tool}

See also:

Inheritance

Constructors

StreamJumpToUnreadButton({Key? key, required String label, VoidCallback? onJumpPressed, IconData? leadingIcon, IconData? trailingIcon, VoidCallback? onDismissPressed})
Creates a jump-to-unread button.

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
props StreamJumpToUnreadButtonProps
The properties that configure this button.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited