StreamMediaViewer class
A full-screen surface for browsing media (images, videos, etc.).
Composes an optional header, footer, and child media area, and
animates the chrome in and out via showChrome. The child is
typically a PageView of image / video players, header a
StreamAppBar, and footer a StreamBottomAppBar — none are
required.
{@tool snippet}
Browse a list of attachments with chrome that hides on tap:
StreamMediaViewer(
showChrome: _showChrome,
header: StreamAppBar(title: const Text('Photo')),
footer: StreamBottomAppBar(title: Text('${i + 1} of $n')),
child: GestureDetector(
onTap: () => setState(() => _showChrome = !_showChrome),
child: PageView.builder(/* ... */),
),
)
{@end-tool}
See also:
- StreamMediaViewerTheme, for theming via the widget tree.
- StreamAppBar, the top chrome typically used as
header. - StreamBottomAppBar, the bottom chrome typically used as
footer.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- StreamMediaViewer
Constructors
- StreamMediaViewer({Key? key, required Widget child, PreferredSizeWidget? header, bool showChrome = true})
- Creates a Stream media viewer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- props → StreamMediaViewerProps
-
The properties that configure this media viewer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited