padding property
Padding around the attachment content.
When non-null, a Padding widget is inserted between the attachment container decoration and the child content.
Implementation
final StreamMessageLayoutProperty<EdgeInsetsGeometry?>? padding;
Padding around the attachment content.
When non-null, a Padding widget is inserted between the attachment container decoration and the child content.
final StreamMessageLayoutProperty<EdgeInsetsGeometry?>? padding;