StreamProgressBarThemeData class

Theme data for customizing StreamProgressBar widgets.

{@tool snippet}

Customize progress bar appearance globally via StreamTheme:

StreamTheme(
  data: StreamThemeData(
    progressBarTheme: StreamProgressBarThemeData(
      style: StreamProgressBarStyle(
        trackColor: Colors.grey.shade200,
        fillColor: Colors.blue,
        minHeight: 6,
      ),
    ),
  ),
  child: MyApp(),
)

{@end-tool}

See also:

Annotations

Constructors

StreamProgressBarThemeData({StreamProgressBarStyle? style})
Creates progress bar theme data with optional style overrides.
const

Properties

canMerge bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style StreamProgressBarStyle?
The visual styling for progress bars.
final

Methods

copyWith({StreamProgressBarStyle? style}) StreamProgressBarThemeData
inherited
merge(StreamProgressBarThemeData? other) StreamProgressBarThemeData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(StreamProgressBarThemeData? a, StreamProgressBarThemeData? b, double t) StreamProgressBarThemeData?
Linearly interpolate between two StreamProgressBarThemeData objects.