StreamReactionPickerItem class

A single pickable reaction item.

Represents one emoji option within a StreamReactionPicker.

{@tool snippet}

Create a reaction item:

StreamReactionPickerItem(
  key: 'like',
  emoji: StreamUnicodeEmoji('👍'),
  isSelected: true,
)

{@end-tool}

Annotations

Constructors

StreamReactionPickerItem({required String key, required StreamEmojiContent emoji, bool isSelected = false})
Creates a reaction picker item.
const

Properties

emoji StreamEmojiContent
The content model describing what to render.
final
hashCode int
The hash code for this object.
no setterinherited
isSelected bool
Whether the user has already selected this reaction.
final
key String
A unique identifier for this reaction (e.g. 'like', 'love').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited