StreamReactionPickerThemeData class

Theme data for customizing StreamReactionPicker layout.

{@tool snippet}

Customize reaction picker layout globally:

StreamTheme(
  reactionPickerTheme: StreamReactionPickerThemeData(
    backgroundColor: Colors.white,
    elevation: 4,
    spacing: 2,
  ),
)

{@end-tool}

See also:

Annotations

Constructors

StreamReactionPickerThemeData({Color? backgroundColor, EdgeInsetsGeometry? padding, double? elevation, double? spacing, OutlinedBorder? shape, BorderSide? side})
Creates reaction picker theme data with optional overrides.
const

Properties

backgroundColor → Color?
The background color of the reaction picker container.
final
canMerge → bool
no setterinherited
elevation → double?
The elevation of the reaction picker container.
final
hashCode → int
The hash code for this object.
no setterinherited
padding → EdgeInsetsGeometry?
The padding around the reaction picker content.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → OutlinedBorder?
The shape of the reaction picker container.
final
side → BorderSide?
The border for the reaction picker container.
final
spacing → double?
The gap between adjacent reaction items in the picker.
final

Methods

copyWith({Color? backgroundColor, EdgeInsetsGeometry? padding, double? elevation, double? spacing, OutlinedBorder? shape, BorderSide? side}) → StreamReactionPickerThemeData
inherited
merge(StreamReactionPickerThemeData? other) → StreamReactionPickerThemeData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited