StreamRetryBadgeProps class
Properties for configuring a StreamRetryBadge.
This class holds all the configuration options for a retry badge, allowing them to be passed through the StreamComponentFactory.
See also:
- StreamRetryBadge, which uses these properties.
- DefaultStreamRetryBadge, the default implementation.
Constructors
- StreamRetryBadgeProps({StreamRetryBadgeSize? size})
-
Creates properties for a retry badge.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → StreamRetryBadgeSize?
-
The size of the badge.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited