margin property
The margin to apply beyond the safe area.
Added to every edge on top of the system inset (or minimum, whichever is greater).
Implementation
final EdgeInsets margin;
The margin to apply beyond the safe area.
Added to every edge on top of the system inset (or minimum, whichever is greater).
final EdgeInsets margin;