StreamSkeletonLoadingTheme class

Applies a skeleton loading theme to descendant StreamSkeletonLoading widgets.

Wrap a subtree with StreamSkeletonLoadingTheme to override skeleton shimmer styling. Access the merged theme using BuildContext.streamSkeletonLoadingTheme.

{@tool snippet}

Override skeleton colors for a specific section:

StreamSkeletonLoadingTheme(
  data: StreamSkeletonLoadingThemeData(
    baseColor: Colors.grey.shade300,
    highlightColor: Colors.grey.shade100,
  ),
  child: Column(
    children: [
      StreamSkeletonLoading(child: Container(height: 20)),
      StreamSkeletonLoading(child: Container(height: 40)),
    ],
  ),
)

{@end-tool}

See also:

Inheritance

Constructors

StreamSkeletonLoadingTheme({Key? key, required StreamSkeletonLoadingThemeData data, required Widget child})
Creates a skeleton loading theme that controls descendant skeleton widgets.
const

Properties

child Widget
The widget below this widget in the tree.
finalinherited
data StreamSkeletonLoadingThemeData
The skeleton loading theme data for descendant widgets.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant StreamSkeletonLoadingTheme oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
override
wrap(BuildContext context, Widget child) Widget
Return a copy of this inherited theme with the specified child.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) StreamSkeletonLoadingThemeData
Returns the StreamSkeletonLoadingThemeData merged from local and global themes.