StreamSwitch class

A switch styled for the Stream design system.

StreamSwitch displays a platform-adaptive switch that renders as a CupertinoSwitch on iOS/macOS and a Material Switch on other platforms. Visual properties can be customized via StreamSwitchTheme and StreamSwitchStyle.

The switch itself does not maintain any state. Instead, when the state of the switch changes, the widget calls the onChanged callback. Most widgets that use a switch will listen for the onChanged callback and rebuild the switch with a new value to update the visual appearance.

{@tool snippet}

Basic switch:

StreamSwitch(
  value: isEnabled,
  onChanged: (value) => setState(() => isEnabled = value),
)

{@end-tool}

{@tool snippet}

Disabled switch:

StreamSwitch(
  value: true,
  onChanged: null,
)

{@end-tool}

See also:

Inheritance

Constructors

StreamSwitch({Key? key, required bool value, required ValueChanged<bool>? onChanged, StreamSwitchStyle? style, String? semanticLabel})
Creates a Stream switch.

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
props StreamSwitchProps
The props controlling the appearance and behavior of this switch.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited