StreamTextInputThemeData class

Theme data for customizing StreamTextInput widgets.

{@tool snippet}

Customize text input appearance globally via StreamTheme:

StreamTheme(
  textInputTheme: StreamTextInputThemeData(
    style: StreamTextInputStyle(
      border: BorderSide(color: Colors.grey),
      focusBorder: BorderSide(color: Colors.blue),
    ),
  ),
)

{@end-tool}

See also:

Annotations

Constructors

StreamTextInputThemeData({StreamTextInputStyle? style})
Creates text input theme data with optional style overrides.
const

Properties

canMerge → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → StreamTextInputStyle?
The visual styling for text inputs.
final

Methods

copyWith({StreamTextInputStyle? style}) → StreamTextInputThemeData
inherited
merge(StreamTextInputThemeData? other) → StreamTextInputThemeData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(StreamTextInputThemeData? a, StreamTextInputThemeData? b, double t) → StreamTextInputThemeData?
Linearly interpolate between two StreamTextInputThemeData objects.