kStreamMentionScheme top-level constant

String const kStreamMentionScheme

The default protocol prefix used to identify mention links.

Links with this scheme (e.g., [text](mention:id)) are treated as mentions rather than regular links. A mention type qualifier can follow the scheme to distinguish kinds, e.g. [text](mention-role:id). Bare mention: is treated as a user mention.

Implementation

const kStreamMentionScheme = 'mention';