separatorHeight property

double? separatorHeight
final

The height of the divider between the two halves, in logical pixels.

The divider is shorter than the halves it separates, which are in turn shorter than the surface. Defaults to the half's own size inset by StreamSpacing.xxs at both ends — 24, since the halves are StreamButtonSize.small.

Implementation

final double? separatorHeight;