SvgIcon class

A icon widget drawn from a provided SVG asset described in an SvgIconData.

There must be an ambient Directionality widget when using SvgIcon. Typically this is introduced automatically by the WidgetsApp or MaterialApp.

This widget assumes that the rendered icon is squared. Non-squared icons may render incorrectly.

See also:

  • IconButton, for interactive icons.
  • IconTheme, which provides ambient configuration for icons.
Inheritance

Constructors

SvgIcon(SvgIconData? icon, {Key? key, double? size, Color? color, TextDirection? textDirection, bool? applyTextScaling, String? semanticLabel})
Creates a svg icon widget.
const

Properties

applyTextScaling bool?
Whether to scale the size of this widget using the ambient MediaQuery's TextScaler.
final
color Color?
The color to use when drawing the icon.
final
hashCode int
The hash code for this object.
no setterinherited
icon SvgIconData?
The icon to display.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Semantic label for the icon.
final
size double?
The size of the icon in logical pixels.
final
textDirection TextDirection?
The text direction to use for rendering the icon.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited