icon property
The icon to display.
The icon can be null, in which case the widget will render as an empty space of the specified size.
Implementation
final SvgIconData? icon;
The icon to display.
The icon can be null, in which case the widget will render as an empty space of the specified size.
final SvgIconData? icon;