package property

String? package
final

The name of the package from which the svg asset is included.

The name is used by the SvgIcon widget to obtain the svg icon from the appropriate asset.

Implementation

final String? package;