StreamAudioWaveformSlider class
A widget that displays an audio waveform and allows the user to interact with it using a slider.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- StreamAudioWaveformSlider
Constructors
-
StreamAudioWaveformSlider({Key? key, required List<
double> waveform, ValueChanged<double> ? onChangeStart, required ValueChanged<double> ? onChanged, ValueChanged<double> ? onChangeEnd, int limit = 100, Color? color, double progress = 0, Color? progressColor, double? minBarHeight, double? spacingRatio, double? heightScale, bool inverse = true, bool isActive = false, Color? activeThumbColor, Color? activeThumbBorderColor, Color? idleThumbColor, Color? idleThumbBorderColor}) -
A widget that displays an audio waveform and allows the user to interact
with it using a slider.
const
Properties
- activeThumbBorderColor → Color?
-
The border color of the slider thumb when isActive is true.
final
- activeThumbColor → Color?
-
The color of the slider thumb when isActive is true.
final
- color → Color?
-
The color of the wave bars.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightScale → double?
-
The scale of the height of the bars.
final
- idleThumbBorderColor → Color?
-
The border color of the slider thumb when isActive is false.
final
- idleThumbColor → Color?
-
The color of the slider thumb when isActive is false.
final
- inverse → bool
-
If true, the bars grow from right to left otherwise they grow from left
to right.
final
- isActive → bool
-
Whether the waveform slider is in an active (playing) state.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- limit → int
-
The number of wave bars that will be draw in the screen. When the length
of waveform is bigger than limit only the X last bars will be shown.
final
- minBarHeight → double?
-
The minimum height of the bars.
final
-
onChanged
→ ValueChanged<
double> ? -
Called while the thumb is being dragged.
final
-
onChangeEnd
→ ValueChanged<
double> ? -
Called when the thumb stops being dragged.
final
-
onChangeStart
→ ValueChanged<
double> ? -
Called when the thumb starts being dragged.
final
- progress → double
-
The progress of the audio track. Used to show the progress of the audio.
final
- progressColor → Color?
-
The color of the progressed wave bars.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacingRatio → double?
-
The ratio of the spacing between the bars.
final
-
waveform
→ List<
double> -
The waveform data to be drawn.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StreamAudioWaveformSlider> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited