StreamAvatarProps class
Properties for configuring a StreamAvatar.
This class holds all the configuration options for an avatar, allowing them to be passed through the StreamComponentFactory.
See also:
- StreamAvatar, which uses these properties.
- DefaultStreamAvatar, the default implementation.
Constructors
- StreamAvatarProps({StreamAvatarSize? size, String? imageUrl, required WidgetBuilder placeholder, Color? backgroundColor, Color? foregroundColor, bool showBorder = true, bool? isFloating, String? semanticsLabel})
-
Creates properties for an avatar.
const
Properties
- backgroundColor → Color?
-
The background color of the avatar.
final
- foregroundColor → Color?
-
The foreground color for text and icons in the placeholder.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String?
-
The URL of the avatar image.
final
- isFloating → bool?
-
Whether this avatar is in a floating state, rendering with a drop shadow.
final
- placeholder → WidgetBuilder
-
A builder for the placeholder content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String?
-
Screen-reader label for the avatar.
final
- showBorder → bool
-
Whether to show a border around the avatar.
final
- size → StreamAvatarSize?
-
The size of the avatar.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited