StreamCheckboxStyle class
Visual styling properties for checkboxes.
Defines the appearance of checkboxes including size, colors, border, and shape. Color and border properties are WidgetStateProperty-based for state-dependent styling (default, hover, pressed, disabled, selected).
See also:
- StreamCheckboxThemeData, which wraps this style for theming.
- StreamCheckbox, which uses this styling.
- Annotations
-
- @themeGen
- @immutable
Constructors
-
StreamCheckboxStyle({StreamCheckboxSize? size, double? checkSize, WidgetStateProperty<
Color?> ? fillColor, WidgetStateProperty<Color?> ? checkColor, WidgetStateProperty<Color?> ? overlayColor, OutlinedBorder? shape, WidgetStateProperty<BorderSide?> ? side}) -
Creates checkbox style properties.
const
- StreamCheckboxStyle.from({StreamCheckboxSize? size, double? checkSize, Color? fillColor, Color? selectedFillColor, Color? disabledFillColor, Color? checkColor, Color? selectedCheckColor, Color? disabledCheckColor, Color? overlayColor, Color? hoveredOverlayColor, Color? pressedOverlayColor, OutlinedBorder? shape, BorderSide? side, BorderSide? selectedSide, BorderSide? disabledSide})
-
Creates a StreamCheckboxStyle from simple values.
factory
Properties
- canMerge → bool
-
no setterinherited
-
checkColor
→ WidgetStateProperty<
Color?> ? -
The color of the checkmark icon, resolved per WidgetState.
final
- checkSize → double?
-
The size of the checkmark icon inside the checkbox.
final
-
fillColor
→ WidgetStateProperty<
Color?> ? -
The color that fills the checkbox, resolved per WidgetState.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
overlayColor
→ WidgetStateProperty<
Color?> ? -
The overlay color for interaction feedback, resolved per WidgetState.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → OutlinedBorder?
-
The shape of the checkbox.
final
- side → WidgetStateBorderSide?
-
The border of the checkbox, resolved per WidgetState.
final
- size → StreamCheckboxSize?
-
The size of checkboxes.
final
Methods
-
copyWith(
{StreamCheckboxSize? size, double? checkSize, WidgetStateProperty< Color?> ? fillColor, WidgetStateProperty<Color?> ? checkColor, WidgetStateProperty<Color?> ? overlayColor, OutlinedBorder? shape, WidgetStateBorderSide? side}) → StreamCheckboxStyle -
inherited
-
merge(
StreamCheckboxStyle? other) → StreamCheckboxStyle -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
StreamCheckboxStyle? a, StreamCheckboxStyle? b, double t) → StreamCheckboxStyle? - Linearly interpolate between two StreamCheckboxStyle objects.