StreamContextMenuActionProps<T extends Object?> class
Properties for configuring a StreamContextMenuAction.
This class holds all the configuration options for a context menu action, including its visual representation, behavior, and an optional value that is returned when the action is selected.
The type parameter T represents the type of value.
See also:
- StreamContextMenuAction, which uses these properties.
- DefaultStreamContextMenuAction, the default implementation.
- Annotations
Constructors
- StreamContextMenuActionProps({T? value, required Widget label, VoidCallback? onTap, bool enabled = true, Widget? leading, Widget? trailing, bool isDestructive = false})
-
Creates properties for a context menu action.
const
Properties
- enabled → bool
-
Whether this action is interactive.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDestructive → bool
-
Whether this action uses destructive (error/danger) styling.
final
- label → Widget
-
The label widget displayed on the action.
final
- leading → Widget?
-
An optional widget displayed before the label.
final
- onTap → VoidCallback?
-
Called when the action is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trailing → Widget?
-
An optional widget displayed after the label.
final
- value → T?
-
The value returned when this action is selected inside a popup route
(e.g. a dialog or bottom sheet).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited