StreamEmojiButtonProps class

Properties for configuring a StreamEmojiButton.

This class holds all the configuration options for an emoji button, allowing them to be passed through the StreamComponentFactory.

See also:

Constructors

StreamEmojiButtonProps({StreamEmojiButtonSize? size, required StreamEmojiContent emoji, VoidCallback? onPressed, VoidCallback? onLongPress, bool? isSelected})
Creates properties for an emoji button.
const

Properties

emoji StreamEmojiContent
The content model describing what to render.
final
hashCode int
The hash code for this object.
no setterinherited
isSelected bool?
Whether the button is in a selected state.
final
onLongPress VoidCallback?
Called when the emoji button is long-pressed.
final
onPressed VoidCallback?
Called when the emoji button is pressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size StreamEmojiButtonSize?
The size of the emoji button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited