StreamEmojiChipThemeData class
Theme data for customizing emoji chip widgets.
{@tool snippet}
Customize emoji chip appearance globally:
StreamTheme(
emojiChipTheme: StreamEmojiChipThemeData(
style: StreamEmojiChipThemeStyle(
foregroundColor: WidgetStateProperty.resolveWith((states) {
if (states.contains(WidgetState.disabled)) return Colors.grey;
return Colors.black;
}),
),
),
)
{@end-tool}
See also:
- StreamEmojiChipTheme, for overriding theme in a widget subtree.
- Annotations
-
- @themeGen
- @immutable
Constructors
- StreamEmojiChipThemeData({StreamEmojiChipThemeStyle? style})
-
Creates an emoji chip theme with optional style overrides.
const
Properties
- canMerge → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → StreamEmojiChipThemeStyle?
-
The visual styling for emoji chips.
final
Methods
-
copyWith(
{StreamEmojiChipThemeStyle? style}) → StreamEmojiChipThemeData -
inherited
-
merge(
StreamEmojiChipThemeData? other) → StreamEmojiChipThemeData -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
StreamEmojiChipThemeData? a, StreamEmojiChipThemeData? b, double t) → StreamEmojiChipThemeData? - Linearly interpolate between two StreamEmojiChipThemeData objects.