StreamErrorBadge class
A circular error badge that displays an exclamation mark icon.
StreamErrorBadge is used to indicate a failed operation, such as a message that could not be sent. It renders as a fixed-size circle with an error-colored background and an exclamation mark icon.
{@tool snippet}
Basic usage:
StreamErrorBadge()
{@end-tool}
{@tool snippet}
Medium variant:
StreamErrorBadge(size: StreamErrorBadgeSize.md)
{@end-tool}
See also:
- StreamErrorBadgeSize, the available size variants.
- StreamRetryBadge, a badge for indicating retryable actions.
- StreamBadgeNotification, a badge for displaying notification counts.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- StreamErrorBadge
Constructors
- StreamErrorBadge({Key? key, StreamErrorBadgeSize? size})
- Creates an error badge.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- props → StreamErrorBadgeProps
-
The properties that configure this error badge.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited