StreamImageErrorPlaceholder class
An error placeholder for image-sized areas.
StreamImageErrorPlaceholder is used as the default error state for image slots. When onRetry is provided, the surface becomes tappable so the user can retry the failed operation.
{@tool snippet}
Basic usage with retry:
StreamImageErrorPlaceholder(
width: 200,
height: 150,
onRetry: () => reloadImage(),
)
{@end-tool}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- StreamImageErrorPlaceholder
Constructors
- StreamImageErrorPlaceholder({Key? key, double? width, double? height, VoidCallback? onRetry})
-
Creates a StreamImageErrorPlaceholder.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The height of the placeholder area.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onRetry → VoidCallback?
-
Called when the user taps the error surface to retry.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
The width of the placeholder area.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited