StreamIntrinsicBoundedCrossAxis class
Marks a child of StreamIntrinsicFlex to be measured under the parent's cross-axis ceiling instead of unbounded constraints.
By default children are measured unbounded so Align and similar
widgets shrink-wrap. Descendants that require a bounded cross-axis
(e.g. ListView with shrinkWrap: true, Wrap) assert under that
contract — wrap them in this widget to opt into the bounded path.
Has no effect when the parent's cross-axis is itself unbounded.
This can be combined with StreamIntrinsicSizeCandidate on the same child:
StreamIntrinsicColumn(
children: [
StreamIntrinsicSizeCandidate(
child: StreamIntrinsicBoundedCrossAxis(child: MyContent()),
),
],
)
{@tool snippet}
A column whose first child needs a bounded width to host a ListView
with shrinkWrap: true:
StreamIntrinsicColumn(
children: [
StreamIntrinsicBoundedCrossAxis(child: BubbleWithListView()),
ReactionStrip(),
],
)
{@end-tool}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- ParentDataWidget<
_IntrinsicFlexParentData> - StreamIntrinsicBoundedCrossAxis
Constructors
- StreamIntrinsicBoundedCrossAxis({Key? key, required Widget child})
-
Creates a widget that marks its child for bounded cross-axis
measurement.
const
Properties
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- debugTypicalAncestorWidgetClass → Type
-
Describes the RenderObjectWidget that is typically used to set up the
ParentData that applyParentData will write to.
no setteroverride
- debugTypicalAncestorWidgetDescription → String
-
Describes the RenderObjectWidget that is typically used to set up the
ParentData that applyParentData will write to.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyParentData(
RenderObject renderObject) → void -
Write the data from this widget into the given render object's parent data.
override
-
createElement(
) → ParentDataElement< _IntrinsicFlexParentData> -
Inflates this configuration to a concrete instance.
inherited
-
debugCanApplyOutOfTurn(
) → bool -
Whether the ParentDataElement.applyWidgetOutOfTurn method is allowed
with this widget.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
debugIsValidRenderObject(
RenderObject renderObject) → bool -
Checks if this widget can apply its parent data to the provided
renderObject.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited