StreamMessageContentProps class
Properties for configuring a StreamMessageContent.
See also:
- StreamMessageContent, which uses these properties.
Constructors
- StreamMessageContentProps({Widget? header, required Widget child, double? spacing})
-
Creates properties for a message content layout.
const
Properties
- child → Widget
-
The body content of the message.
final
-
Content displayed below the body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
Content displayed above the body.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double?
-
The vertical spacing between the header, child, and footer sections.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited