StreamMessageTextProps class

Properties for configuring a StreamMessageText.

See also:

Annotations

Constructors

StreamMessageTextProps({required String text, EdgeInsetsGeometry? padding, StreamMessageTextStyle? style, bool selectable = false, MarkdownTapLinkCallback? onTapLink, MarkdownTapMentionCallback? onTapMention, MarkdownTapAnyMentionCallback? onTapAnyMention, VoidCallback? onTapText, MarkdownImageBuilder? imageBuilder, SyntaxHighlighter? syntaxHighlighter, Map<String, MarkdownElementBuilder>? builders, Map<String, MarkdownPaddingBuilder>? paddingBuilders, List<BlockSyntax>? blockSyntaxes, List<InlineSyntax>? inlineSyntaxes, ExtensionSet? extensionSet, bool softLineBreak = false, bool fitContent = true, MarkdownStyleSheet? styleSheet})
Creates properties for a markdown message text widget.
const

Properties

blockSyntaxes List<BlockSyntax>?
Additional block-level syntax parsers.
final
builders Map<String, MarkdownElementBuilder>?
Custom element builders keyed by tag name.
final
extensionSet → ExtensionSet?
Markdown extension set.
final
fitContent bool
Whether the widget sizes to fit its content.
final
hashCode int
The hash code for this object.
no setterinherited
imageBuilder → MarkdownImageBuilder?
Custom image builder.
final
inlineSyntaxes List<InlineSyntax>?
Additional inline-level syntax parsers.
final
onTapAnyMention MarkdownTapAnyMentionCallback?
Called when a mention of any kind is tapped.
final
Called when a link is tapped.
final
onTapMention MarkdownTapMentionCallback?
Called when a user-type mention is tapped.
final
onTapText VoidCallback?
Called when non-link text is tapped.
final
padding EdgeInsetsGeometry?
Optional padding override for the text content.
final
paddingBuilders Map<String, MarkdownPaddingBuilder>?
Custom padding builders keyed by tag name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool
Whether text is selectable.
final
softLineBreak bool
Whether soft line breaks are treated as hard breaks.
final
style StreamMessageTextStyle?
Optional style overrides for placement-aware styling.
final
styleSheet → MarkdownStyleSheet?
Additional style sheet for customising headings, code blocks, tables, and other markdown styles not exposed in StreamMessageTextStyle.
final
syntaxHighlighter → SyntaxHighlighter?
Syntax highlighter for code blocks.
final
text String
The markdown text to render.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited