onTapAnyMention property
Called when a mention of any kind is tapped.
Receives the StreamMentionType decoded from the URL scheme along with the display text and the URL-decoded id payload. Takes precedence over onTapMention when both are set.
Implementation
final MarkdownTapAnyMentionCallback? onTapAnyMention;