StreamOnlineIndicatorThemeData class
Theme data for customizing StreamOnlineIndicator widgets.
{@tool snippet}
Customize indicator appearance globally:
StreamTheme(
onlineIndicatorTheme: StreamOnlineIndicatorThemeData(
backgroundOnline: Colors.green,
backgroundOffline: Colors.grey,
borderColor: Colors.white,
),
)
{@end-tool}
See also:
- StreamOnlineIndicator, the widget that uses this theme data.
- StreamOnlineIndicatorTheme, for overriding theme in a widget subtree.
- Annotations
-
- @themeGen
- @immutable
Constructors
- StreamOnlineIndicatorThemeData({StreamOnlineIndicatorSize? size, Color? backgroundOnline, Color? backgroundOffline, Color? borderColor})
-
Creates an online indicator theme with optional style overrides.
const
Properties
- backgroundOffline → Color?
-
The background color for offline presence indicators.
final
- backgroundOnline → Color?
-
The background color for online presence indicators.
final
- borderColor → Color?
-
The border color for the indicator.
final
- canMerge → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → StreamOnlineIndicatorSize?
-
The default size for online indicators.
final
Methods
-
copyWith(
{StreamOnlineIndicatorSize? size, Color? backgroundOnline, Color? backgroundOffline, Color? borderColor}) → StreamOnlineIndicatorThemeData -
inherited
-
merge(
StreamOnlineIndicatorThemeData? other) → StreamOnlineIndicatorThemeData -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
StreamOnlineIndicatorThemeData? a, StreamOnlineIndicatorThemeData? b, double t) → StreamOnlineIndicatorThemeData? - Linearly interpolate between two StreamOnlineIndicatorThemeData objects.