StreamPlaybackSpeed enum
Predefined playback speed values for StreamPlaybackSpeedToggle.
Values
- x1 → const StreamPlaybackSpeed
-
Normal speed (1x).
const StreamPlaybackSpeed(1, 'x1') - x2 → const StreamPlaybackSpeed
-
Double speed (2x).
const StreamPlaybackSpeed(2, 'x2') - x0_5 → const StreamPlaybackSpeed
-
Half speed (0.5x).
const StreamPlaybackSpeed(0.5, 'x0.5')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
The display label for this speed (e.g. "x1", "x2", "x0.5").
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - next → StreamPlaybackSpeed
-
Returns the next speed in the cycle: x1 → x2 → x0.5 → x1.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
The numeric speed multiplier (e.g. 1.0, 2.0, 0.5).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StreamPlaybackSpeed> - A constant List of the values in this enum, in order of their declaration.