StreamSnackbarClosedReason enum

The reason a StreamSnackbar was closed.

See also:

Inheritance
Available extensions

Values

action → const StreamSnackbarClosedReason

The user activated the action button.

swipe → const StreamSnackbarClosedReason

The user swiped the snackbar away.

timeout → const StreamSnackbarClosedReason

The auto-dismiss duration elapsed.

dismiss → const StreamSnackbarClosedReason

Programmatically dismissed via StreamSnackbarController.close or StreamSnackbarMessenger.hideCurrent. The exit animation played.

remove → const StreamSnackbarClosedReason

Removed without an exit animation. Fires when the messenger is disposed, StreamSnackbarMessenger.removeCurrent is called, or StreamSnackbarMessenger.clearSnackbars is called.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StreamSnackbarClosedReason>
A constant List of the values in this enum, in order of their declaration.