SvgIconData class
A description of an svg icon.
- Annotations
Constructors
- SvgIconData(String path, {String? package, bool preserveColors = false, bool matchTextDirection = false})
-
Creates svg icon data.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- matchTextDirection → bool
-
Whether this icon should be automatically mirrored in right-to-left
environments.
final
- package → String?
-
The name of the package from which the svg asset is included.
final
- path → String
-
The path of the svg icon, e.g. 'assets/icons/heart.svg'.
final
- preserveColors → bool
-
Whether this icon should preserve its original predefined colors.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override